@@ -1,6 +1,7 @@
 from .objects import PhotoObj, SpecObj
 from .regions import Region
-from .utils import (decode_objid, decode_specid, sql2df, binimg2array,
+from .refs import manga_ancillary
+from .utils import (decode_objid, decode_specid, sql2df, sql_columns, binimg2array,
                     img_cutout, show_spect, show_object, download_frame)
 
-__version__ = "0.1.7"
+__version__ = "0.2.0"
